SystemOrganization addCategory: #ExternalIconFamily!

TestCase subclass: #ExternalIconFamilyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExternalIconFamily'!

!ExternalIconFamilyTest methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/10/2010 06:09'!
testAccessingIcon
	| name family star root resources starFile writer  resources16x16 spec |
	name := 'familyForTest'.
	root := FileDirectory default .
	root assureExistenceOfPath: 'familyForTestResources'.
	[ 
		resources := root directoryNamed:'familyForTestResources'.
		self assert: resources exists description: 'precondition'. 
		resources assureExistenceOfPath: '16x16'.
		resources16x16 := resources directoryNamed:'16x16'.
		self assert: resources16x16 exists description: 'precondition'. 
		star := Form makeStar .
		starFile := resources16x16 fileNamed: 'star.png'.
		writer := PNGReadWriter on: (FileStream fileNamed: starFile fullName).
		[ writer nextPutImage: star ]	ensure: [writer close].
		spec := ExternalIconSpec named: 'star' file:'star.png'.
		spec resourcesFolderName: resources fullName .
		ExternalIconFamily createFamilyNamed: name specs: {spec}.
		family := ExternalIconFamily named: name.
		self shouldnt:[ (family iconNamed: 'star' size: 16) ] raise: Error.
	] ensure: [
		ExternalIconFamily deleteFamilyNamed: name.
		resources recursiveDelete. ].	
! !

!ExternalIconFamilyTest methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 09:25'!
testCreatingEmptyFamily
	| name family |
	name := 'gauchoXXXXXXX'.
	[ 
	family := ExternalIconFamily createEmptyFamilyNamed: name.
	self
		assert: ( family name includesSubString: name );
		assert: family isBehavior ;
		assert: family = ( ExternalIconFamily familyNamed: name ) class ;
		assert: ( ExternalIconFamily subclasses includes: family ).
	] ensure: [ ExternalIconFamily deleteFamilyNamed: name ].	
! !

!ExternalIconFamilyTest methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 09:26'!
testCreatingFamily
	| name family star root resources starFile writer  resources16x16 spec |
	name := 'familyForTest'.
	root := FileDirectory default .
	root assureExistenceOfPath: 'familyForTestResources'.
	[ 
		resources := root directoryNamed:'familyForTestResources'.
		self assert: resources exists description: 'precondition'. 
		resources assureExistenceOfPath: '16x16'.
		resources16x16 := resources directoryNamed:'16x16'.
		self assert: resources16x16 exists description: 'precondition'. 
		star := Form dotOfSize: 50 .
		starFile := resources16x16 fileNamed: 'star.png'.
		writer := PNGReadWriter on: (FileStream fileNamed: starFile fullName).
		[ writer nextPutImage: star ]	ensure: [writer close].
		spec := ExternalIconSpec named: 'star' file:'star.png'.
		spec resourcesFolderName: resources fullName .
		family := ExternalIconFamily createFamilyNamed: name specs: {spec}.
		self
			assert: ( ExternalIconFamily subclasses includes: family );
			assert: ( family selectors includes:#star16x16 );
			assert: ( family new perform: #star16x16 ) bits = star bits ;
			assert: ( family uniqueInstance  == (ExternalIconFamily named:'familyForTest')).
	] ensure: [
		ExternalIconFamily deleteFamilyNamed: name.
		resources recursiveDelete. ].	
! !

!ExternalIconFamilyTest methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 09:25'!
testIconCreation 
	| family icon |
	self assert:  ( Smalltalk classNamed: 'ExternalIconFamilyOxygen') notNil.
	family := ExternalIconFamily named: 'Oxygen'.
	icon := AlphaImageMorph named: 'copy' size: 32  family: family.
	self
		assert: icon notNil ;
		deny: icon isOpaque.
		! !

!ImageMorph class methodsFor: '*ExternalIconFamily' stamp: 'FernandoOlivero 11/14/2010 09:21'!
named: aName size: anIconSize family: aGMIconFamily 
	^ self new named: aName size: anIconSize family: aGMIconFamily ! !

!ImageMorph class methodsFor: '*ExternalIconFamily' stamp: 'FernandoOlivero 11/14/2010 09:21'!
named: aName size: anIconSize familyNamed: aFamilyName 
	^ self named: aName size: anIconSize family: (ExternalIconFamily familyNamed:  aFamilyName ). 
! !

!ImageMorph methodsFor: '*ExternalIconFamily' stamp: 'FernandoOlivero 11/14/2010 09:23'!
named: aName size: anIconSize family: anIconFamily 
	| form |
	self externalName =  ( aName, anIconSize name , anIconFamily name )  ifTrue:[ ^ self ].
	form := anIconFamily iconNamed: aName size: anIconSize .
	self name: aName, anIconSize name , anIconFamily name.
	self image:  form.
	! !

Object subclass: #ExternalIconFamily
	instanceVariableNames: 'iconsGroups aliases'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExternalIconFamily'!

ExternalIconFamily class
	instanceVariableNames: 'uniqueInstance'!

!ExternalIconFamily commentStamp: 'FernandoOlivero 11/15/2010 15:19' prior: 0!
This framework allows importing and managing any external icon family. Once imported , the icon family is reified into the image,  as a subclass of 
ExternalIconFamily. 

Subclasses of ExternalIconFamily act as caches for all the forms, that were requested previously.To load a form send 
ExternalIconFamily>>iconNamed: aString size: aNumber 
AlphaImageMorph named: 'document_save' size: 32 family: 'oxygen'. 

As an example it comes with a tiny subset of the Oxygen icon family imported, to load others see the example named OxygenIconsBuilder.

To open at all the icons provided by an imported family send #openAllIcons to any subclass of ExternalIconFamily.


How to import?

The external file directory, from where to import the files should have all the desired icons, categorized by sizes in directories named 16x16, 32x32, 64x64, etc... 

Every icon family builder responds iconsSpecs, which is the specification of all the icons to import. 
IconsFamilyBuilder>>iconsSpecs is automatically created with the contents of all the icons in the external folder. But this can be overridden in any subclass, for loading any subset of all the available icons. ( See ExternalIconSpec class). 
The importer creates valid selectors from the icon file names, and later creates aliases. For example, "AlphaImageMorph named: 'document_save' size: 32 family: 'oxygen'", the icon contents are retrieved using a automatically defined alias, so you can the original file names 

To load evaluate in Pharo 
Gofer it 
squeaksource: 'ExternalIconFamily'; 
package: 'ExternalIconFamily'; 
load. 


Try out this example 
ExternalIconFamilyOxygenTinySubsetExample openAllIcons 
 
!

ExternalIconFamily class
	instanceVariableNames: 'uniqueInstance'!

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 4/21/2010 18:25'!
availableSizes 
	^ {8. 16. 32. 64. 128}! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 11:27'!
createEmptyFamilyNamed: aName 
	^ self
		subclass: ( self name , aName ) asSymbol 
		instanceVariableNames: ''
		classVariableNames: ''
		poolDictionaries: ''
		category: self category asString 
		! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 12:38'!
createFamilyNamed: aName specs: aCollectionOfIconSpecs
	| family |
	family := self createEmptyFamilyNamed: aName .
	aCollectionOfIconSpecs do:[:each| each createInto: family   ].
	^ family ! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 7/26/2010 21:06'!
default 
	^ self familyNamed:'Oxygen'! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 11/14/2010 09:35'!
deleteFamilyNamed: aString 
	| family |
	family := self familyNamed: aString .
	family notNil ifTrue:[ 	family class removeFromSystem ]! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 11/12/2010 14:41'!
familyName
	^ self name last: ( self name size - 'ExternalIconFamily' size  )
	! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 7/26/2010 21:05'!
familyNamed: aName 
	| subcls |
	subcls := self subclasses detect:[:each| each name asLowercase endsWith: aName asLowercase  ] ifNone: nil.
	subcls notNil 
		ifTrue:[ ^ subcls uniqueInstance ]
		ifFalse:[ ^ nil ].
	! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 4/26/2010 08:25'!
iconsCategoryName 
	^ 'accessing-icons'! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 4/26/2010 08:26'!
importedCategoryName 
	^ 'accessing-icons contents'! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 11:04'!
loadFrom: aCollectionOfIconSpecs 
	| family |
	family := self new.
	aCollectionOfIconSpecs do:[:each| each loadInto: family   ].
	^ family ! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 11/12/2010 14:56'!
loadedIconNames
	^ (self allMethodsInCategory: self iconsCategoryName) .! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 8/2/2010 11:44'!
named: aName 
	| family |
	family :=  self familyNamed: aName.
	^ family  ! !

!ExternalIconFamily class methodsFor: 'examples' stamp: 'FernandoOlivero 11/15/2010 15:26'!
openAllIcons
	| sizes family iconRowsMorphs i j rows row columnSize  rowsMorphs columnMorph  w names  scrollPane |
	family := self uniqueInstance.
	sizes :=	family availableSizes.
	names :=  self loadedIconNames  collect:[:each| family iconNameWithoutSizeFrom: each asString ].
	w := StandardWindow new.
	iconRowsMorphs := names asSet collect:[:each| 
		row := OrderedCollection new.
		sizes do:[:eachSize|
			| form  image |
			form := family iconNamed: each size: eachSize.   
			image := AlphaImageMorph withForm:  form.
			row add: image ].
		w theme newRowIn: w for: row  ].
	columnSize := 4.
	j := 1.
	i := 1. 
	rows := OrderedCollection new.
	row := OrderedCollection new.
	iconRowsMorphs do:[:each|
		row add: each.
		j = columnSize 
			ifTrue:[ 
				i := i + 1 . 
				j := 1. 
				rows add: row. 
				row := OrderedCollection new ]
			ifFalse:[ j := j + 1 ]].
	row notEmpty ifTrue:[ rows add: row ].
	rowsMorphs := rows collect:[:each| w newRow: each  ].
	rowsMorphs do:[:each| each width: 1000 ].
	columnMorph := w  newColumn: rowsMorphs .
	columnMorph extent: 800@800.
	scrollPane :=  w  newScrollPaneFor: columnMorph.
	w
		addMorph: scrollPane 
		fullFrame: (LayoutFrame fractions: (0@0 corner: 1@1) offsets: (0@20 corner: 0 @ 0));
		themeChanged;
		openInWorld
		
	! !

!ExternalIconFamily class methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 17:23'!
uniqueInstance
	"
	uniqueInstance := nil
	"
	uniqueInstance isNil ifTrue:[ uniqueInstance := self new ].
	^ uniqueInstance

  ! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 12:09'!
aliases
	^ aliases! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'unnamedDeveloper 8/9/2010 23:13'!
cacheAllIconForms
	^ self loadedIconNames ! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'unnamedDeveloper 8/11/2010 11:29'!
createAliasOf: anIconName named: anAliasName 
	aliases at: anAliasName put: anIconName 
	! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/18/2010 11:31'!
createIconNamed: aString size: aNumber  
	| iconName form group  |
	iconName := self iconNameFrom: aString size: aNumber.
	form := self perform: iconName asSymbol.
	group := iconsGroups at: aNumber ifAbsentPut:[ Dictionary new ].
	group at: aString put: form .
	^ form! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:05'!
defaultIconName
	^ self subclassResponsibility! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/17/2010 13:52'!
defaultSize
	^ 32! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:25'!
definesContentsForIconNamed: aString sized: aNumber
	| suffix |
	suffix := aNumber asString , 'x', aNumber asString, 'Contents'.
	^ ( self class methodsInCategory: self class importedCategoryName )
		anySatisfy:[:each|
			( each  beginsWith: aString ) 
				and:[ ( each endsWith: suffix )
					and:[ ( ( (self class >>  each )
						getSource copyAfter: Character cr) =  '	^ '''''  ) not] ] ]  
! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:44'!
definesIconNamed: aString
	| symbol |
	symbol := aString asSymbol.
	^ self loadedIconNames includes: symbol .! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'unnamedDeveloper 8/11/2010 12:50'!
iconNameFrom: aString size: aNumber
	| installedName |
	installedName := aliases at: aString ifAbsent: [ aString ].
	^ installedName , aNumber asString , 'x', aNumber asString. 
	
! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/12/2010 15:23'!
iconNameWithoutSizeFrom: aString
	| stringSize tailSize |
	stringSize := aString size.
	( aString endsWith: 'x128')
		ifTrue:[  tailSize :=  '128x128' size ]
		ifFalse:[  tailSize :=  '64x64' size ].
	^ aString first: stringSize -  tailSize.! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/17/2010 14:25'!
iconNamed: aString 
	^ self iconNamed: aString  size: self defaultSize .! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:55'!
iconNamed: aString size: aNumber   
	| icons defined iconName hasContents |
	iconName := self iconNameFrom: aString size: aNumber.
	defined := self definesIconNamed: iconName.
	hasContents := self
		definesContentsForIconNamed: iconName
		sized: aNumber.
	( defined not or:[ hasContents not] ) ifTrue:[ ^ self iconNamed: self defaultIconName size: aNumber    ].
	icons := self iconsOfSize: aNumber. 
	^ icons at: aString ifAbsentPut:[ self createIconNamed: aString size: aNumber   ]
! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/26/2010 08:25'!
iconsCategoryName 
	^ self class iconsCategoryName ! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/17/2010 17:20'!
iconsOfSize: aNumber 
	^ iconsGroups at: aNumber ifAbsentPut:[ Dictionary new  ].
	
! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/17/2010 14:08'!
importedCategoryName 
	^ self class importedCategoryName ! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 11:24'!
initialize 
	super initialize .
	iconsGroups := Dictionary new. 
	aliases := Dictionary new.
	! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/12/2010 15:15'!
loadedIconNames
	^ self class loadedIconNames! !

!ExternalIconFamily methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 11:24'!
useAllAliasesIn: aDictionary 
	aliases := aDictionary .! !

ExternalIconFamily subclass: #ExternalIconFamilyOxygenTinySubsetExample
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExternalIconFamily'!

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
apply16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self apply16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
apply16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAFMSURBVDiNpdKxapRREAXgb9b74yp5BG0sJFhbWaSxURBMI2TBJpjkAQJCIJUQsLKRQArF
BRfUQsEiEGULxTLgA1jkJVKYGFfHYm/C6m6QJAMD994z5zBz5kZmOku0zsQ+rUCsx6VTC8RG
PHXO19iIaxAn8SCexRMs1+sOpo86iG5cjW4c21F047FiWUHxXbGQizloQfTiumJb8SJ6EWPk
XjxSrFTyvuJuzudnCK8UfMOVWv8cS9kZzhavYxVrFTvAbHZy61C8lZ0caMxp7GrQWNBYh3gb
DzXW6vtPjXujZEZMjPdxAx8xVbEvmKnnAeZyNt+NjTe6hdiMGWzh4kjNL9zPO/lmorn/rjE+
xE1soo3fmM9b+XISGWTmWOq7rW9P34NJ+F+1xwKfXP4fOTNP9hMnRTmaPaKNC4YGtnG+4mm4
hQP8qLmPvcwc/AE4pbcHcRdePgAAAABJRU5ErkJggg=='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
apply32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self apply32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
apply32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAADdgAAA3YBfdWCzAAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAK5SURBVFiF7ZdNiE1hGMd//3OvGZqGRCZRSikLC8pCUvNd0+RrQkk0viOlLGRhNWUhCyVF
42PykUwuysT4ZkY2FhYWFooopUg0SZg7M3+LuVfnzpwzc+8wZsFbT+/tPM/z/n73fe+5517Z
ZixHMKb0/wL/jIBSSuiodiulxF8XUJMCPnCOBEf4wDk1KYeZHFU4EmW0AOsyl9ZRRlpok+m/
/0dtB4REM80ENBJkSP3RSDPNQhpVAU5xlATbBsD7I8FiTjARRukIdFqHCdgVk35BH9Xe7i6I
2AG1qFRndUwtKh0R/IwOkmBP5DsPeAVUeavfZ+tzBHReJSRpR+wkyU2dV0lB8LNqImBfDPwN
ptKb/S6nJ/swUkoT+EE7UBHKd1BMvdf427DwC9qPORCZNG+Bcm/w60F9ttEZjaeINqA2ov0e
3SzzRn+PhV/UXsyhmPQ7+ij3er+MSgY5r6KjhvFcVUpFkfBW7UYciul9j6iOg8PAI2DQEYRH
G59Z7e1O/2q+pB2I4zH1Hwmo8Co/j4PnCEDmQ1jCLcySmPorTGGtK9yjq9qCOQkoou4TAVVu
8LOh4IMEANSmUnq5AyyK6WlF3MacJvqLrAtR7ZV+Ohw8UgBAKU2iiHvAwnwWCY0vQK1X+Em+
DZECALqhyfTyADE/z7W+Iuq81I/zhQ8pAKDrmop4CMwbZp1vmHovdUch8GEFAHRH0+ihEzE3
puQ7ZrnrfbdQeF4CALqt6UAnMGdAqhvT4Dq3jwSetwCAbmomSTqB2ZlLacQa1/jaSOEFCQDo
gWZhHgEzgLWu9uXfgRcsAKD7mk3AAlf6yu/CRyTwp8e/8b9gqJHzm1BSEigCxoXmZGZOhELk
PoQM9GWiNxQ9EZEGemz3/hKQJPp3IxkCZiWyURySygoFGWga6M5EOjSH5YKQuCQFtvt+Alc4
9axxjmQBAAAAAElFTkSuQmCC'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
apply64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self apply64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
apply64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:29'!
availableSizes
	^{ 16 . 32 . 64 }! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
bell16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self bell16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
bell16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AALESURBVDiNdZO/b1t1FMU/9/10HNuN4zr+FQOWgmgjxFCWwlamRjAAAx1hBFHBglRVQipI
MPEHIFUMBSTSCjF0gBQhkaFSBwiuINSVEhKaCCdNQuWmznt+9ve975chpXJTONMZ7j3n6Opc
McYwjI9q5RdSvv/JeLE8lS9XM9EgCu5s/rVyZ2f7nXPtrascgAwLfDxZ+aZWrL0yfeyYFB6r
k65V8ctl3PE8f1753sxd/PLrM0urp4YFrH/JB7XSFyU/9+qRw4cloxSyu0t/aRnVbhOtrFKs
1+Xk8yde+3Cy9NkjCc7Uiscr2rt2xPUkXyjgKIUEAVYcI56HXangNRr07u2y3mzqZjE8ea65
88MDgferE98dJTVTs218DL4ZigYYwFgWW9WY+XJEdvJxsn5w21VbrzsALtbTWWt/xbp/EnFs
8jMzqM1NugsLGK2ZT/3N2Xdfwp94Am+iXl6f//SsA2AbGXPlgRca2IgVO60Wo7aQMobYN/S1
YmSwyNq1OdzRAld/C5+zAProdgLo+xIaEKW49MsCtxdvYAAZCPXxFINeSH4sw969Lgs3g1UL
ICT5KdSaxBgUoA3kbZeZdJq0bZEgaAPT7UOsXY9ob3aSH68nYdVSXQugm45Pr2kVKWAAKAEE
Sq5H1nZQGJTASMdi8XMnuHwlVbHDnE4Fas4COL9yt3vL6r+1YxITARHQFyEWQYnQF6EH7KFN
U0VvPPPs9JvZYMOPYmYfauLbk4UXnzL+Vw1xc/ZQyzSwQdxpSe9U/YT3ay59qFXoLF14+ZJ5
T4wxXG486S+Pj4XH73atvTjm5mCP0CQ4QC/RGG2YEIeqP0LB81lPlPk2dysz+7sJHYBAa7u0
vW2NjmQYtW1Kvv9QieTgB8UDuXiDZBZwAGJgN0lQBwf/B50kYWpqnzvsOyStqEfD9Q6Myn8w
+DmT5o9lNMA/FjE5oWRRqhwAAAAASUVORK5CYII='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
bell32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self bell32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
bell32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
bell64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self bell64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
bell64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:29'!
defaultIconName ^'messagebox_warning'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
deleteUser16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self deleteUser16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
deleteUser16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAJDSURBVDiNjZLPSxRxGMaf73e+zu7O/tJ2V3JTSrODhv1SEIog6hQYQdExBIsIoXPnDh06
lBVd+gO0g5idOnUIIkqzKF1BJTZr1w3RdXd1ZnZ2Zr7zdqlImwVfeC7Py/uB5+EFEcFP0+P3
Bz9NPuyvt/8jRkT4d96O3TtlVq1XpmkFky2tCAUDawJu+sjATRc+w3carqRRSSwoicCFilgy
nVKEOuZ3DABipxGJRVMnug8DgQSIAOk5WCws9+4K8HVqNJZKNhpcBDQlGAAXARARWva1fa8H
2BbBrqpeNBrJAxwM7LdLiDfFl3YF6D5zRZe2exfSAqQFcgzI6lZNcHZ7VwAASPZdnsj/yJK0
KiDbRGZ2ZjPSebpSD/BfiQBQYyF97vPHqGVLJPa2L9Y79gVkMvPqwa7eiGXq+LaUwZ6W1kOu
6zEhOPkB/j6S48g225a3arY95Ni1eAiGqJQ3KNzcUY1GwivZxw/eVN69HshNvDwKQG+9cO6L
kSs8YkSE1dXSMOPKk3BYZUJRQETgfHs9M4OXkNKSWCksG3Nr6+b5Y32pXCH7k+XyKxGjikpz
Ks5DQbVuVkfXMX31IgJlC1u2DSjuanZ6vkdsmuxOolHjDICUHjhnvgAigmPWoM1nEPM8rDeF
pQ5AVMpGtKFBIU16LBFsgOf5doUPw9fRO7uA5wc6qLill68Vi2m1p2uKERFGRsZDoebk2ZPH
O28oCmtjYDHGmQaC5xEZINrMvpgsFZ897V7Il/q1jUIp3b7/vee6I78A4B8qvPSUtKkAAAAA
SUVORK5CYII='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
deleteUser32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self deleteUser32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
deleteUser32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
deleteUser64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self deleteUser64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
deleteUser64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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=='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
documentSaveAll16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self documentSaveAll16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
documentSaveAll16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAIISURBVDiNlZO/T1NRFMc/9/U1DfTtFvwD8A/QRBoTRcUEUBNTTRjcTGRQMcSBzcFVxI7+
AWwwuLg6+RfQUUpim0Zo2pr6ymsf79x7HB60UAbDWe69Oed87/dzfxhV5Ww8XFwK4zgOXr1d
g9OUAWM8jGfIGAMGyhsfyeVyPZ+xiPpRcG1mhnv3H6DnBAyeAc8zZDzD151tqvvV4IKAtY5+
f8BELsOX7e8jAUw6NfCyNIeIYK3jgoBzFhEhEcuLJ7fTDlVUwaniVAn7x4gIzlnM0sJiyry6
NlK5wKyUNzaYyAfcKq2wvFBk/c0Kv2o1/CHz/P+Yd6juV3l05zphFKcOrMW/LPOH9VWc03Tt
LP5lmY/CEFXFGIOzLnUgInSPYra+/Ridg4KSCi0vFIcOfu7t4dRxdWoakQTf2dTB3yjm8dyN
Ub+CqqKq55gLhSs0m03yQcDvgwN8e4Lw/t1rjBm7Uz0dRsxJkiAiZDyDJAm+sw4rQtQLx5/E
GTcj5lqthqqyu1vBGNPzRRLiOOZT+TOtVot8Ps/k5OSw8VnpKYoyXZhCJKHeaHgnOQXwj48T
BoMBlUqF8uYms8UiN2dnh7sXpgo0Dw8JTph17Pf5ViTphWG23W7TjyK63S6dTmdYkMQxiQjG
pMzj4avq8/afzlaj0cjenZ8nm81Sr9eHBbV6HVWlUkmZxwX+AYDDdmXqFV2MAAAAAElFTkSu
QmCC'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
documentSaveAll32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self documentSaveAll32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
documentSaveAll32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAADdgAAA3YBfdWCzAAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAUOSURBVFiFtZZNjxzVFYafc6tqetozo7ExnrFnZLyIlOQ/sAkSEl8/BQkhAYkMSFmZRMqe
rLPPKosIJAIRLFgnNki2VyDNMHLbHuxpd1fdW/ecLOqjq6q7QXHiK3XXR9+u8573OafuFTNj
ON6/fv04+HCluX7xNy/zi1/+mixJYDBfREAEJ4KIQ0TqD1AfnVTzQij55ta/+PLzzwAYj8cn
6VJ04PTh6ZWbt26yv7/P3qU9zm1v89zF59nc2Fg1Ham/pBYkw3MBJ8Ks8Gxv7zCdTgEIIVxe
KUBV2draJkszVBURSJxQxrg6eCugzry5boLXYpyT9vnNca2A3d1dRqNRJQBwzrG9mQHQQFgE
l/a8ESD1PWmFCNPcI0MB773z7rH3vuX90iuv8dZvP1zi/XAy4fQpeH/2yd8B2Nvf582330FR
mrozM9LpdFrzvszepUtsbe9w8eIlRhvZKnP+a97eewAm9+5RRkWjtQ5EjaQV7y2yNK3tNtz/
g7cIgvXsjlGJ3XtRKwHnd8+3vAGSRNga/W+8n8wLkD7voIpG7deAmbGzs9MyERESJ4QVDiyy
Xy2qEWQGaqBmPd4Ngl4NNGqa4TASBzvn6p4fWCD0h9UPMusfcx8w1R7vMirRBg4MBVQTjOm8
WGmA1V+NrjZwLYT6WtWIRo93KJUY408LUIUQlSzNFkU2CIqwsBEwqYWItC4UIS4FK2MkRsNa
UbGqgZ4DUSlL5bGudmAhZKFo4UD9qa2JylINRDO0vqeraiDGSFBl5JLV8QXEDJA2c5HaClkI
CzEStc/76y8/5843//65GjBCGfFhTRc0+VvnquNAcy7CEoJ//O2v/SepktpQgCplVJKmqXv/
MKx/2RGxODejzb7LeylZjaS6VANGiEq5Jv9uoK6otjsakXUNdHkPY6muqIGvv/onDx88JJ/P
10nAVtywzi9msDkec/fbPu/J5B4xRvb39qt5qxB8d/c23929vTb40w6r9xje+58uwmc1osb6
LWqUZVmfsVwDz2qoGlqzip11ZglBM159/TWuXbsGNNVu7WIlItXS7Vy79JoZDx484M8ff4xz
rl5++7wtKqPNTc7v7nL//v1KwDoEB4eHbI7H/PHGRy2zJ7MZN/7wUTtH6jZt3nZXX3iB8eaY
NE1RsyXeZVmSpin5fE4sSzAjbXgMhy8Kio2NdkcDcHb2mNls1rrQFWJmpGlK86ZYxTuEwNbW
Fo/PzihjrGogrln353lOmmXEjkM+BMqypLt+VLtmaW0HwWAlb+8LJpMJhwcHnJycVG24TkBR
FGRZhnZ+Dz6Q5zlQ7ZKHI4SAYWiMmNkS7xBKTJWjo6PKFTPSuBaBx2/4XgahXDhgZsQYe0Xp
nKP0AUvTKrsB71gLa55pZiFdtfkEKHxBVmR9AaFkNpsBC+5NZzQIQgjVGmC2xPvoh+O/AArg
RDSU5fdpLMsT4PKSA94TQmByf0LhPRoj4hx5nrfZDodzDh88SXSY2RLvHx89+qAz3YAiPTs7
e2M8Hn8qIs/3ERT40YjfXb/eVryqtq3VONNtxSRJCD6gSVK5M+ANnAK9RSb99s7t4wu75/90
9fDw90mSnFtkk1QPDGEp024buvpl1NzvdsmQN3ABmFunjVJgevroxy/yIr8wGo0OAD04OIh3
7tz+1eZ4PMqybJSl6SjLssw5l7kkSQWcgWrUEDUGU/UhhGKe50ESd/foh+McSIa8AW+DPeB/
AGXdSLn7GY5PAAAAAElFTkSuQmCC'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
documentSaveAll64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self documentSaveAll64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
documentSaveAll64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
editClearHistory16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self editClearHistory16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
editClearHistory16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AALPSURBVDiNpVNpSFRhFD3ffc/3jamjM9miY1AmJWq0oFFC2iIFUvRHSC0KSYNAECLTjJIo
IUzMMCFaMBIxIpAswmhxKYOmxgRzRS0bwQlNZ9xm5s18vf44UQb+6cL5de493HMPl2mahv8p
eTHyTm7kourZN4aYDACFRfkGIUS8ECLBK0SC8HqjqipvbqgPKVttDOC1UeGBakNbV78qoImf
FODV/FauijDkZAOQL14uLlM4PyWEYMLrhSQEhCSZAaDfOpFRc/5Qj7IkyP18JrnRoAChOvhv
WmqLrbj/NAPAFeKcF8qS9IkrChTOfRgEAI0HtqaVto2ZrWg/ugXI2Qrk7YCp6UPPcqe05DUA
kNvlMrnd7tifmgauKD4MAMDArfR3ju/DMVNjI+60jUBqNEDeMf+Oz/3LHLWZZgCQiegCEXHn
3Bxkvb5W4fywEGLAd6h44/r0qvv1T7obh+UQfbDf4yHDbGpc3EEfT4yxrUQEInLaJydzuKKc
UBSlz9fQVL3TtSyFp5rHQ5XWUT3bu1vZX1280/U7RiIKmxd4W1Z6zQng9j95WYA5MvYCkmSx
iL8oIiIbYwxEtLng7OnAhbNrspp11gk8unpyz5u7+ft6/fwCGnZlNev+tPBqfoNQIspdKPD9
R9+DnMzUh+HcLne2PTNVF6QMdM301fh4dqW0JEYIYfF4PDpVVV2qqlZ6PJ6SivJKR2Leg0Sn
yg5vD+qKmh37khwbF8P1QSHu5pHgFy8HcWm8NtNMBflF3UR0et6Gjoi2EZEKAJNTM0kxouWI
mB7dq2kat3xsR0tLM5ds75JkMbcbAAgACs+cqyKi40TUQkQHysuuOwEg0mSs67CH2zutTnyz
TcD2YwZf7RLej69wrI0w1gEAW+wbS46t04J1AnbHNIymaOiNYZiaGMX4SB9k/2AU3etniwow
xgiAHkAQgAAAEgAPgFkA0wCmfwHL0yESXwUNGQAAAABJRU5ErkJggg=='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
editClearHistory32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self editClearHistory32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
editClearHistory32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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=='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
editClearHistory64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self editClearHistory64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
editClearHistory64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
helpAbout16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self helpAbout16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
helpAbout16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAJcSURBVDiNpZM/TBRBFIe/N7M7y3Ec/w7loNIEhcLEQmMhlbGzEAsxYEwsaAyJtobE2FiY
aGMoDA2JVhCwEC2osDPRRo2NkRALRXLAnhjvuLvdu72x4Nw7xM5JfpnM5OWb937znlhr+Z/l
/H0hF5Y92ksTotR4f3eytwYd2V+VTxbmEW/RPj2f2xffnIGMvRzp6TAzF09lMoP9bfj5EAG6
21tYzZZYeu/ncoVoxD459/oAQK4tDw9kWl9dPtNnHK34kQ94MD6ECEwtrNLelqBaszx7lwvX
/PCKnTm7BKAA5PpKOt2ZWBoe6jF+MSJbqJJOuSQ9TavR9HW2kM1H+MUaw8e6TE97YkZurXkN
DxwZPdqbSueKFqQGInzZLrPwdhOtYWU1T0siASIgwpHDyYy/XpgAHjsArvHG0Q6bxb1yoqhG
MYi48+IriJBqa0VbQACxoBxcx7saAyriHP+4WaEz4eC5mqAcsPnwdGxu7+0PeEkXBIIIfpYj
Ksrtjj1AuzuhddgqCesF8CsGdeNNDNguw/ddWN8VtsqKUFxw3K4mD0xurz6FFcGKgK3FACsa
q0zsAaJA+NyUgZlDG9BuXQZUU49pBxy3LlPfvfkGIFSzOO5GHCAKoqgBiKK9lx2zB1PKx3iL
McBODwRoM4k2AdqFaoidPtko4dEJCEt/jgGiL9mpVO5gK9/bGsaq56oW9WScEv0pxaGkkC1Y
vpUT+KHaACbt3fTSP2cBQO7n01SDUayMKWFQCTvVms0hMkfnzqy9ORDsi49nQcQALU3y6r+k
gAioACFQrqtkra3+Bs+a45V/FOo4AAAAAElFTkSuQmCC'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
helpAbout32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self helpAbout32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
helpAbout32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
helpAbout64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self helpAbout64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
helpAbout64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
messageboxWarning16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self messageboxWarning16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
messageboxWarning16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAJ3SURBVDiNjVFdSFNhGH6+HSfFOLLyD+fcps6ZkAheFIdM3KCgLgIvCk8hEbS6Co6BXRmE
eTcIqguF8KLCIMibqAy7McEY0U0IBS0tN5u6ubXOzuaZnnPeLtwWUwkfePn4vu953p/nZUSE
nWCMMQANADz5p28AIrQXmYh2BYDWQCAwIctyQpblRCAQmADQuid3D7FFFMVhw9B15fdCJpta
zBqGoYuiOAzA8t8EeQixaGhVy0ZIWRwl5cc4aRsrlFgLrQMQdnZt2jERL0mSWF3nrlVXXkJX
V6GrUeTWpnC4xl0pSZIIgC/xq1CZMQar1do9//nj0xr+j0NZuI/xNwfBcRyunNFgabyGhMIv
2xxtfQDmih0XWjGbzfzQ0NAoEVFs1kcr063k9Xqpq6uLolNOis16iYhIkqQHAPgSDwDAbrf3
RJe/L+cSHygyCYpMglwuF7lcruJdjc9QNPzlF4ATheImAOjt7a30+/19dfXN9enQPYBx24bw
PHj+38jy1zuoa2izDQwMXCh4YQJgyWQyx6/7+89tJoNQV18DpAMAOpsVdDYrxQS5+Axy6+9x
6+bV8wDaGWPgBEFwV1RU+E+dPnsy+ekyNCVUFPg6UvB1pErWpGd/orZ9kJdlORMMBueYx+Px
vZt++6jWEm6Kz/aUkG/c3T4f3i7ddXX3DOLZ+qUGZ8tFU1VV1VGHs7EpFX6VxT6hhJ/rdofb
KQjCsTJVVXOGYWgW9+CWWn5ILee2DhSIj5/tFm9q5o0y2yWViKyGYWgA0DIyMvIklUrFaJ9I
p9PJsbGxFwCOMAAMgA1AG4AaAOUAzADKAHD5fwKg5WMLQBLAPIClvw++kiXuJ2FeAAAAAElF
TkSuQmCC'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
messageboxWarning32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self messageboxWarning32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
messageboxWarning32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
messageboxWarning64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self messageboxWarning64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
messageboxWarning64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
plus16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self plus16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
plus16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AALKSURBVDiNZZNPaGNVFIe/++5L8jJNmjApIQmxtOCMtmD/WC0BZ6GL6kLoysEi6HI2FqRL
abddF7fuXKiMuDMgs5iFRaQDUjMlg06D2FQqvo4kbZImNy+597qY5jG0B35wFr/zncPhHGGt
5WpUq9W7Usq7SqmSEMJ2u93q2NjYd/Pz819d9YoXAQcHB8VIJPIglUrNep5HNBpFCIEQAq01
h4eHp8CdpaWl2qjGGSX7+/uv9Hq9PxOJxGw8HkdKyQhurUVKyczMTDafz/++s7Pz3jWAEOKH
TCYTjcViz4swPDl7zJPGY876zXDK8fFxubKy8vX09HQsBOzt7X1qrb3leV7YcaCH+J1/Ob3w
uQguMMaEE01OTmbW19fvh4BWq/Wh67qhwRiD0ZpOv01btQkGCq01xpiwQalUui2ESLkAJycn
r01NTRGYgId//4iDg0DQCTpIJAf+bxz+9xSJ5NXsLLlEgVwulwNuuZVKRSilkkoprNHs1h/S
D/qofh/V72G0JSY9POERl3E+mPuI9Es3GQ6H6WQy+bKzsLBgG41G8+zsjG6nR1KnyDhZcpE8
p+c+z859ojrKRDTLmEhiAkOn06HVav3Tbrc7LsDExMQfWus7N7jBvdnPcByHnu7xqP4LVlve
mVrh3dvv4zgOQgiCIKDZbNaAugPQ7Xa/Pz4+ZjAYhIvCWszwuV48VmMMQRCwu7tbBY4dgI2N
jS/q9frTIAhQSmGtxXVc3iyUeKNQIpfIh9tXSuH7/q/b29s/WWvP3RG5Vqt9kk6nHywuLqaF
EMRiMTbe+hwpJQCDwYDhcEi73X62tbX1LVC+9gvLy8tLq6urX87Nzb2ezWZxXTcEXP7Cz5ub
m98cHR3dt9Y2rgEuTzq1trb2caFQeLtYLBYjkYj1ff+vSqVyVC6Xy8Aja60O/SOAEMIFvCu6
CbhAF2gBfUBdqmetNf8DvDpoXqgWRFEAAAAASUVORK5CYII='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
plus32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self plus32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
plus32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
plus64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self plus64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
plus64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAAG7AAABuwBHnU4NQAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
ABCzSURBVHiczVt7jBxFev9V97xnd2Zndtfe9bKsfV5jO7aJLmsWCxufAgQLFEQsgQyEiM0F
MA5ECLAUfNEFRQLJREYIkcR3QZZj8YcPNgFLYAyKsXiIx2HjM8p57bUcOPxY79nend159fSr
vvzRXT09vd0zs/aiS61KXd09VfX9fvV9X31VXcuICH+ItGfPnnYi+hFjTJJl+dsHH3zw0h9C
DvZDE7B79+5MuVweYozdkUql+pLJZHtLS0sqmUyGY7EYTNOEqqqoVCpGpVIplMvlyUKhMFYq
lQ6dOXNmz44dO777IeX7QQjYtWtXT6FQeDSdTt/d29u7sre3V+7s7IQkSWCMWR17ru7EOcfE
xATGxsbo7Nmzpy9cuLD//Pnze1566aVjcy3rnBLw4osvLm5tbf23JUuW/FlfXx/LZrNgjDnA
/TJQJUHI4r3m83mcOXOGjh8/fvjo0aN/v3Pnzs+ISJ8LmeeEgGeeeSbd09Pz8rJlyx5csWJF
OJFIOAAlSYIsy5AkyerQNeLe0ffeE1FNVlUVo6Oj5rFjxw689dZb/3Do0KHjRGRejexXTcD2
7duf7e/v/9n111/fmkqlHNChUAiyLFudNFD7RveARQbnHEQERVEwMjKifvnll69t27bteSL6
/ZXKH7rSioODgy3333//G+vXr7+zr6/PUXMBnDEGIgoE4/e8XmKMQZZlEBESiQQGBgai3d3d
T2Sz2Rv7+vr+5syZM6eISJ0tjivSgI0bNy7asGHDu2vXrv2jtrY2yLIMWZYRDod97dtv5Os5
wRoBA96bpgkiQqFQwKeffnpu586dP/34448PE9HUbLDMWgO2bNmy7p577nl79erVHfF43FH3
UOjKlKmeNggt8kuSJIGI0NLSgttuu+2adDr9X93d3U8wxt4noovN9j8rqTdv3vyTdevW7R8c
HEyGw2FIkoRIJHJF6jwXSZgFANx4442tnPPXGGOPM8beJaLxZtpomoDBwcHFDz/88K9Wr16d
FF49Eok475u162YdoBj5elogngvfMDg4GKlUKjuOHz9+gTF2pBnnKDWU2BKi/YEHHvjVDTfc
0OUe+XpAgp6JKW02980kYYY33XRTeuvWra/GYrF+xlh7Q2yNOmCMtTz33HOvbtiwYSibzSIc
DiMajTpze1CA43WGIhWMPDhxq22rAzAIh2g9bQ2nILHauMErZ9C9pmkoFosYHh4+tHXr1q0A
ThFRKQhfXRNgjMmPP/74X61cufKhdDrtTHMiqKlTz1fIklnE6PRxECzwEiQANklEYEwCA0NX
YgG6Ez111d8PPGCZQzKZxLp162558sknH3rllVd+wRg7RWSz7kmNTKB78eLFP1u8eDFzR3XN
COQOZ0XZ5CZ0roNzE5xzGNyEyQ0rE4dp3+umXlN3NlO1JEmQJAmLFi3CmjVrhtra2voAdAf+
PugFYyz91FNPPXbdddddI0Y9FovV7dwvlHWXRTRnchMGN2Fw3SkL8AY3wYn7qngjItxOUZIk
rFq1Kr1ly5afAuhmjKVmRUAymZzf39+/ecGCBc5cX08Aoa6NsgXYGnWvFggiOOc1oP2cYj2y
BQmdnZ1Ys2bNn3d1dfUB6GyaAMZY9rHHHnuip6enQzgyEeU1mpLqlTlxG3x1xE373k0EwV8D
3OVGcggH3dfXl3j00Uf/GkAnYyzTFAGRSKR93rx5f9nR0VETg3uXqX6de7P3Ofeou5cIkeu1
0yi5Sejo6EB/f/+tnZ2dPQCyDQlgjKWHhoZ+kslkstFoFIwxZ86vF5z4CTuTFO6ovwOcbLvn
3CbFcKZJv/b9+gpKYo3S1dUV27hx460AMl5f4KcB6Y6Ojr/o7KyajB9Ytw0G2emM5yDX6FdH
3PIFussH+GtSkCx+SdRjjGH+/PlYsmTJAIA2ADUE1MQBjLEQgNaWlpaB1tZWAJgR8QUJEOQf
3M+JE0xuAGB2oGPP/2BgkCBCIm7vcbiJDurHOxBeGUOhEFKpFDo6OpYBaAWQYozJZG+keDWg
5c4771wWDoe7xCJHrPKCQtbA0fZ5bjlBa5ozuQnD1GGaJkxb/U1uwDANZ+OjXrteOYLeCwyx
WCx11113/dgmoVW89xKQXL58+d0i1PVObfWE8BNoxnOQRYJpBTucc3AyXTOBAZNMxwcE2X0z
PsBdjzGGWCyGgYGBNQDiABLid95QOJ5MJpdGo1GnYqMpZ0rLwYSJakQPWOGtuNpxPoBpbQqG
qQO2whO4tQAgQAKzfg8GxShjUpmo3UARrTNRZs5aIhVthSzNjOrds0E8Hkcmk7nGJiA+gwDG
WBhANBQKZcLhsFPR3Zh3RC8oY/jk4n/XCCRBsmN98dRug+zdIfuPOyXU3APAmenf4ez099Yb
AphYGNnvJZsu0c+i7GKsnP/HM4C7HWE0GkUsFmsFEAMQY4yFiMhw0xYBEJVlOSUiMT8NcDeq
mgpMbrpEq4VijTO3JWVgVH0DIscRMhcZcJeYZBEH0ybPAs7BbSIsDavolRmD5HWUnHNEIpFW
G6fIMwgIy7Lcqus6iMjZdgoKSjiRTYBLLe0RYwBAtmkwBpB7vAFGDBxkA6sCZzZZVgtm9Tlj
VTLBILEq1SJw8mqAKDPGoGkaZFlulSQpzDkP23jLbgJC0Wg0zBiLExEMw/BVpxpNsL03asAz
CzhVdYCBObZOwglyw/IHRJClMEJSCCEWsq5yGDKTLNJY1TsQqurPHWIBzmd+GvAOlmEYkCRJ
WrZsWXZkZEQGIAO1TlAaGBjotNFAaEGQJ2aMgRNHXs2jpBZR1kpQdAW6qdtL2uq0Znl9A4ap
2VMc7JGkaplssm2OGSTITILMZMgsBFkKOSTFQjG0RFNIxVNoibYiHUmDcx64IBM7yACwcOHC
+SMjI5IfASyXy1XEjaZZwkqSBNM0HY0QiyMiwreX/heffHcIIA8QkAtUFWzNPZHzuAa8uJAJ
TiY00gPqV/spFYoY7FpbQ4B7R0rIDgCKomiOynoIwIkTJwpEZBBRaHp6GvF43ImnxQcPUZYk
CcRpJnhhJo6w5ICCG7ywJi/4JsiaWd8qcs6twMo0nbJhGI4GEBFGR0cviiEBagMhAsBN0ywR
EXRdR6VSQf0UoMJe8DWCN6jjB97ze1/CvZK5TNcwrOiSc66OjY0VXFTWEMABmJzzgqjsdoRB
zlAI67bfYPBeIM0Q5k/WjHsf4CIJf6ZpWhHW1CJyjQkYAAxd1wtCjTRNC5xeAGBl9se4dcEd
0LnukFFloKqaIp7LVXL4zfjhQLKEqVybXojrssuqNcnVOMGeUar3ty29o0Y+rxOsVCoCT97G
qfsRoFtk6ZdtdYFhGL5eVeS4HMd9/Q85DQR9+hblExO/xdELX9WAnTHqIKzoXIWhP9ncsD13
OWjNIsyZc45KpZIHoLlIqDEBHYCmqupnQgPczmM2C5G6qVmVn22zAfIJUzYMA2fPnj0JQLWz
VkMAWZ+W1TfffPNjwzAMQUC5XK7bwf8H8EHyudXfMAx6//33vwJQAaCSfcLEuxyunDt3brpS
qXwnWCuXy4GNizXDbAVt7Oxm16YwWT8Zi8WiwHH+5MmT520CnOnNS4ACQOGcfyII0HXd1xTc
Hc6OAXi0oLlprW6TLpm8WdM06LqO8fHxEYHPzr4ElACUP/zww4OGYZCu69B1Hfl8fkYnbhJm
J2z9GME7rTVKbrDeQcrn8xAYDh8+/LWNrwSg7EuAbRfFzz///HeKopwWlRVFqQHsJaFpU3CD
hY8JiN80yUCQLCKXSiVomoZSqTT+3nvv/UYQQK4TZn67wkUAhZGRkX/VNM3Rglwu50vCrE3B
R+V9g50rBO8efU3ToGkavvjii30A8gAKNglOCiKgODw8fKRYLP5WNFKpVJyIKojxZkjwBSv8
YpMmEGTvIpumiWKxCFVVkc/nv3/99dcP2eBFDiaArM/IeQD5I0eOvKppGqmqClVVMTk5Wbfj
RiQ42u0D3u0T6uF3gxeLHq8mXLp0CULmQ4cO/Seqo58nj4BBH0enAUwfOHDgf6anp78SGqCq
KqamphqSEOgTfJydv0P0r+4dZb9+p6enxdlj5HK50bfffvszG0/OvtYk3wMSRMQZY1MAEu+8
886LmzZt+g9ZllNiGRyNRpFMJgH4H3MVm6nus8EAsCjzI9y88BaUtXJNHQbmgGYA1i/+U688
dW1ekFGpVFAoFFCpVKAoSvmNN974dxv4FHxGH2hwRIYx1gWg+9577715YGDgpWQyGYrH40gm
k8hkMs5+gTiU4D42I74riHfNnhX0++wtNMqtXUILxHtVVTExMYFyuYxSqcQPHjz4L3v37j0A
YBzABQo4MNXolFgOQHR4ePjXixYt2inL8t8JUCIlEomaCl4NEKMndmf8zgy764qr38rO7eXd
GqCqKi5fvixGHidOnHh37969B235cwAmgwA2c0gqBWAegPkvv/zyz03T3BCPxyFyW1sbEolE
oAYI0H4EeDVAEBVEgB8JlUoFk5OTUBQFiqJgfHz82LZt2/4JwCUAvwcwTkTFKybAFjADYH4i
kZi/devWV1Op1Kp4PI5YLAZhEuLIrABWjwAvcD8C/MB7icjn826bx+Tk5OkXXnjh57lc7pxN
wEUiytXF1mwAY5+5myfLcuf27dufZozdHY1GIYiIRqPIZrPOyVEB1HuUbjYaID5ouAkRtj8x
MeHMTIqiYGxs7NfPP//8P2uadhHAhA1+oiGu2cTyjLFOAO0A2p999tlNmUzmb+PxuByNRsWn
J8RiMWQymRrn5x71qyUgl8tBURRnnldVlU6dOrVvx44du2HZ+gSAS82AnzUBtrDtNgnZoaGh
9UuXLv3HWCyWFCREIhFEIhHEYjGk0+kavxBEgLgP8gFC3cWI67ou5nrtyJEjv9y9e/d+WFNd
DsBlIgp0eldNgC1sG4AMgMzy5ct7Nm7c+HQmk7k5Go3KkUgE4XAY4hoKhZBIJBCPx2sOWXoJ
8BJhmiYURUG5XIZ7aW6H5nT58uWvh4eHf/nNN9+chhXgTAGYJKIZwc6cE2ALmoB15KQNQPr2
229fvnbt2qdbWlpWhMNhiBwKhRAOh51vCkIjxHcGSZIcNRd7kO4tObG3LwgoFArffvTRR6/t
37//KKzwVoCfIqJyHZHnlgCbBBlA2s4pAC2PPPLIut7e3qFEIrEkFArJbgK8U6X3yK17mnMT
oOs6L5fL342Ojr6za9euA7BWdEVYMf40gGm6wv8dmpN/mmKMxWERkIR1/CRx7bXXtt933323
JpPJW5LJ5DJZliNCA7yOUST3FGeaplEul09fuHDhyw8++OCDkydPXoK1kSHAFwEUiEjBVaQ5
/bc52yxaYB1BEScxYu3t7clNmzbd0N7efo2u672xWCwbDoczoVAozRiTDMOY1nV9SlXVCUVR
Lmma9v2+ffu+Pn/+vNjGrqC6lVUCULxa4I7Mc0mA0yhjUdjgXVkcSgjB+jJrHxNzDnsQ7K9T
sPbtNVTBi1yzmzMXqdFxefEZWXJl7703M89VHEaI2uWQpw2ROKoEiPqARYwEi8Q0Y4yjSlZQ
Nj1XTgHH5Zk99zKXUEJA2fVMDsji997feMnyI1E8EyAJ1W929cCYPuV6z+pmoQGCUWZf3f8U
wOpkqc7zRloi+hSJXHXhee4mSXKVvX2K3/rJBC+pRNRwP8APbBCoeiPvtXm4rkFg3ZowQ6Ux
U1NEJs+V+22EiPR/nxrX/pn3l2kAAAAASUVORK5CYII='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
redo16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self redo16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
redo16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAKuSURBVDiNnZM9TBRRFIXPe29m3iwzA8K6CBvFRUQCKAZjJCYWbkeilYmlhaXGysbE0Fka
EyNWNtpKYUjEwkaxgM6oBYJ/+BMXfxaWXWaXt/tm5l0rCBG18Nb3fPfenHsYEeH3yk932+kg
PdDvD5/ukFlvWX19Mleen5k4Pqt+72VbAQdfHxS5UN7qax240J5Ks4xsA+cCFV3DsipSofrm
Hq2Ki3dPPq1fmT9zJsNbX2wChqZ2ZvvSh54PdvZ3AGbbVgAAEliuLRXjeGWq3R88v7L2Ms+I
CL3jTHT1HC30du/fZUwCBobVKERBfQfnAvuacnAYYDEBwTgEdwAi1NVC3gIAuSM3HrS17lqq
FUEA5sMPWKkW4WmbPMfDJ+cD8x0f/X4PmiwPBILNHdgA2OAEhBX169TeJg4An9RXiEIUN73n
14UjbkqHaceyL9MBMUa+YV2pHMA5LG7Dw2reKv4I+jK7Iyo1Ko26aVTjmioF2h17e+3HxMbp
JyZ6klSLw1whQSZCnBDqrArbRNwSjI9UXbWg4qhci2ultJYltzN5uCG+9O6U29btXSXNiIhB
6xo1jAZgIqXEomUMwkpcng95vWLIVHbCKdcjtunt7d5HdQAyP9mNRoUcppHYAiRtyzw49wbW
utYzzVXnSDlIQgBh4iehG8scgIWtDopIWOXsGqkkMh9HVzcHWGGX+t6+7i8iwDqA9RJUbX86
03piusdl2tRjInhVm0WBYWusIRSL4q1gTmeJqEqzGQoKLre+ecL5+VmVVmRKuLGglCDY6ACe
jS5GzcLVvpDbX5ndYRj2d/d+yZQSjzm62ZLaF3Itxe3Y5tw8Pv72L6+5JQvBDcmHBrNB7Cdk
DMUtlmz4QprJkbntafsTAADYNMMxew+vaIXDO7J0f/jVP8XbAP9TvwCl7UU6c7KijwAAAABJ
RU5ErkJggg=='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
redo32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self redo32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
redo32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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=='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
redo64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self redo64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
redo64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
reload16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self reload16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
reload16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAF3SURBVDiNpVG7S8JhFD33YfZwaamhggwJmoyGKIgWB4ceQ1E0hGNBNUgQ9Ac0REPQ0OAQ
LU0JFrRIi0vRC6JagmgThMagVEy7Df4EK83AA3c53/nuPedeMjPUA67rd60GNB/r5LnY0Z+a
ShFoNiput3vFzDYAeAw8mDuYuPl3g5bQSQSEhR/0JdSm3/cmUzUjpLPZJWUKq/CbCkOFP1R4
SE3O25ajnpoN7HCm8Lo/vqPCfaJ8rMKjKpxS4e58zrNeM0IltC/G10C0BcPDSyToL/FaLupY
Pr0ErJWBseRu8Ln8TVx8RcVZPVUjqDCrSC+rrvx04BKZcvbxWLWBCMWLIgp5w4kgEYgI5A0n
gioUUmGIULzqDrpWL5qaOXcHWK9DlWL4imp6Shca+pPbw5mKDpLbw5lGsYCKOE7Yp8I+lzJc
IvFGtkD5518OyjGwfuY3tkEAoE+6vt0cua+k+/cZq+HbGYmIAYjDi1ME4BNAwak8gII5k78A
HmN2cvN7InQAAAAASUVORK5CYII='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
reload32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self reload32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
reload32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAADdgAAA3YBfdWCzAAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAL1SURBVFiF7VdbSFRRFF1r3xm11KGyCFEIIlEpiFAU6iOijxQl/HEIKkLCnx6mkvjhZ0ZF
YWVBmFmIf06UVDLUTwhJGBPRRw/pAUERhUFZaq+5uw+dvHOdOy+1CFqwOXPv2WfvdfdZZx+G
qoq/Cfmr2f8TmAsC3HElV7Zd7Ut2vSvpxF6fIW73PkOlFYKMP0ogZXtfkdud0gGgCEw29SSY
yDGk15eRmpZ6CIr9AAzrnBIXDcqF8e7Ku/NCIH3njSqleQZgbjQ/BR6JavNYz9b+eOLGL0IX
IAKIMKoZwtU05FpmTf/+OSUwdqmyb2H6t0JSTwkRFAJRTAht99RcPxorbkIaCGFRbX8RTEyK
cBqvAKyw+5rQ9aNdzrpIqg987Ky4/+nzeCnJeiG+CInFZnqBkEeE9i2R06TzWUmqAlZk1fpz
SZ4dOV9WBQBLa/2tIFqsPqqo/tBZfnleCMwI6PWlLFuS+QLA9Gkh2t+fKzsQyX/O7wLtrf4u
Ij1C4rcBa5z8HTth9p5bTYRuBgAq3sL8sfdNR+V4PCQEfBz+aUycgGGwAcrs0LO6Uu4A6IqH
AA1NpVp0RwSdyTpNUAJhTQZSEk/yyaBSEraWEkiYAIGAdR8NYUVend8TK3lend9jCCusawkk
TsDltlVAmBN0pbXFIhB0pbWJMMe61uV2roDjMaTXZ6zMzRokUGp9r2CX/Pza+Ky9fNT6Pq/O
7zFdaW0Edof7Y+jl65EN2lsdUQdR+0BB8+18M4gHABbYpt4A6Ffy3lSQEgAVAHJsfhNiYN3T
Y5uGnXLEbET5BwcaSI1Z+khQZePwiY0no/nEJECChU0D9SAOY2YlnDABRcuT4xtPqSJqgrhb
8drmwfwgg92waeJ3oOlxiGrsenhsg2PZkyIAAF6vz3i6avkWgMWqWkyyeCpIgGTAhAYKnr+7
2esguFkTmA/8+39MZouIlxFJYlJXYjNaxpCFoBYzLWOY2bfc6TYMeZm24KGKhUhgaoyUUO2/
I+ntF7XFAHbZGkUjAAAAAElFTkSuQmCC'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
reload64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self reload64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
reload64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
remove16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self remove16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
remove16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAKXSURBVDiNpZPLS1RhGIef75xvzjeO2eR4mzJsapzSatHFNEoiaBMECoZdIDCTiKL/oKK/
INq6yIKkVKLIjUSLoIVZbiKCPFNjeUGhnHEujZ0ZZ8avhWH3Tb3L9/Lw3n5Ca83/mPzVERFC
KUUXUp40q6urAG/h06cxhOg38ua96lQq9mO++LGD6WLZalRWdBcdafG7tm1HWGo5kM+TC4/h
PH4UI55qXTfzcfg3wJTPs98VDD7Ru5us3JcMa7bWIQwDhAAhSNhhTLcb+eb1YmF66ti6d1OD
AAbAzPrVZdK/drAQ3GLJ5oNUXbnK3MgL8rEYS/F55p49p+zCRay9+8jXBCzh93dHQiG1AoCi
dhmsLcsmU6xubMQdCrH+2nWir14TffmKqkuXKd61m5LGJhYTSWRgo9/j9XStjDBbv+mpq37b
AS0EiWicmhs3cYdCZMcj5OIJVjU0kHkbZvL8OUprqhHCID8eGV77dKR5uQNhbM59eE8hFqXE
bTLRcYps5B0qWLtcHLaZONOJ11uCnp+nMD0FUvq+n1GpOIbh1wsLkHHQC1nyiQTfboDWGp3N
spRMIQzAMEDK0u87UFYMpUBZJDN5NvTeobhhD449hmPbFNXVE+i9Q/KLA5aFUAphqfAKwHCr
PqEU6cUlAnf78ezYiWPbTHR2MNnZ8Q1SR+DWbdILDlgK7Xb3rwDSHl+PsNSsS5p8Hh3FsW0m
u06zprIcr7+CybNdOGGbz6MvcFkWQsroUo57Pz3Sx5bDrdowBzLJlMppWFXuQ5gmQgi01qTn
5pHSoMhXmhWaQ5UD94d/e+XZ40f3m4KHQPlftDML+kJV/4PBP2oBYKatrczlol0b4gSaLUBc
C2Jo+tIpp6d2aCj7VzH9i30FmYkOE891ISEAAAAASUVORK5CYII='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
remove32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self remove32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
remove32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
remove64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self remove64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
remove64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
world16x16
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self world16x16Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
world16x16Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAlw
SFlzAAABuwAAAbsBOuzj4gAAABl0RVh0U29mdHdhcmUAd3d3Lmlua3NjYXBlLm9yZ5vuPBoA
AAL2SURBVDiNbZO/a2RVHMXPvXN/zbvOexMzWSI7uhG2isHmgcE1wS1mi0AajYWVhf+DwhaS
0sLKwkKbFDZmMLEUi9FFA0EUbIIYcWQ3G3WVyZhR58f7vne/1yZI1D314XAOnI+IMeKy9vf3
nw4hvC6lTJl5Kcuyz8bjcd05d0dr/VGn05le9otLAaLb7b5HRK8qpYqFhYWPjTFnQggmosXB
YHBLKfWVMeaNzc3NL/4XsLu7e4eZb7RarU9rtVrTWvuHUupHAIgxiizLXhmNRq7f7wfn3O2t
ra23AEACQLfbvc3MzydJAmutcc41nHPPWmu11hrGGLG4uDjL8xx5nteqqnpzb28vB4Banuea
md+en5//OkmSYZqm3zvnHmitv5FSIsuy57z3c41G47oQAlprxBjlcDh8ZmVl5V1VFMWL3vsH
WZb9ZK39WWsdpZQBQFNKeUVKmSVJ8lRZlqiqCiEEeO/hvV/Z2dmxql6vyzRN7xpjYIyJWmtI
KUFE14QQLQBzZVmCmRFjBBEhxgjnnGo0GjdVkiSslMLFVmitBTNbZl6QUtqqqmII4UhKOQfg
KhGhLEtIKU+zLDtXQohfpZTQWsNaC6VUHI/Hj4YQjDGmD2DCzLaqqieZeUJEv5Vl+R2Ax5VS
91WM8R6Afxqcn58vDQaDjlKqVpZlW2s9BOAB/B5CeKwsSyGEuGeM6fd6vV/UbDa7b4wZCSEy
YwxGo9E1IqrFGMHMoqqqeSEEADwSY/xBCHF08Z2j7e3tKDc2NqqiKN4nImit0W63jwD8SUQg
IhRFgaIoMJ1OG5PJ5CozF8w8JaIP/vXEg4ODl5eXl2+maQoiwmQyUcfHx7dms9kTAMDM8N5/
opS6S0Q7a2trX/6XBRweHq632+2XrLU2hICzs7MrJycnL1x4/rLWfm6tfW19ff3bh8EEAOj1
eq1ms3nDWrsUQrh+enraYeaR9/4d7/2Hq6urs4fSKISoAagDcAAsAANAARAAIoASAAEoAMwA
TGOM/DceaHCJeO4SKgAAAABJRU5ErkJggg=='! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
world32x32
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self world32x32Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
world32x32Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons' stamp: ''!
world64x64
	^ Form
		fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self world64x64Contents readStream)! !

!ExternalIconFamilyOxygenTinySubsetExample methodsFor: 'accessing-icons contents' stamp: ''!
world64x64Contents
	^ 'iVBORw0KGgoAAAANSUhEUgAAAEAAAABACAYAAACqaXHeAAAABHNCSVQICAgIfAhkiAAAAAlw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'! !

Object subclass: #ExternalIconSpec
	instanceVariableNames: 'name file resourcesFolderName sizes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExternalIconFamily'!

!ExternalIconSpec class methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 09:26'!
named: aName file: fName 
	| icon |
	icon := self new.
	icon
		name: aName; 
		file: fName ;
		sizes: ExternalIconFamily  availableSizes.
	^ icon 	! !

!ExternalIconSpec class methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/21/2010 18:21'!
named: aName file: fName sizes: iconsSizes
	| icon |
	icon := self new.
	icon
		name: aName; 
		file: fName ;
		sizes: iconsSizes.
	^ icon 	! !

!ExternalIconSpec methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/26/2010 08:27'!
base64ContentsOfFileNamed: aString 
	| fs base64Contents |
	fs := FileStream readOnlyFileNamed: aString.
	base64Contents := (Base64MimeConverter mimeEncode: fs binary) contents.
	fs close.
	^ base64Contents! !

!ExternalIconSpec methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/26/2010 08:34'!
createInto: aFamily 
	| root familyFolder all existing |
	root := FileDirectory default.
	familyFolder := root directoryNamed: resourcesFolderName.
	self assert: familyFolder exists.
	all := familyFolder directoryNames .
	existing := all select:[:each| sizes includes: (each copyUpTo:'x') asNumber  ] .
	existing do:[:each|  self importIconIn: (familyFolder directoryNamed: each) into: aFamily ].
		 ! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 11:06'!
file
	^ file! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 11:06'!
file: anObject
	file := anObject! !

!ExternalIconSpec methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/26/2010 08:36'!
importIconIn: aDirectory into: aFamily
		| fileResource stream imageContents iconGetter selector |
	fileResource := aDirectory  fileNamed: file.
		selector := name , aDirectory localName.
		stream := ReadWriteStream on: (String new).
		stream
			nextPutAll: selector ;
			nextPutAll: 'Contents' ;
			cr ;
			nextPutAll: '^ '.
		imageContents := self base64ContentsOfFileNamed: fileResource fullName.
		imageContents storeOn: stream.
		stream nextPut: $..
		aFamily compileSilently: stream contents classified: aFamily importedCategoryName notifying: nil.
		iconGetter := '' writeStream .
		iconGetter
			nextPutAll: selector ;
			nextPutAll: '^ Form fromBinaryStream: (Base64MimeConverter mimeDecodeToBytes: self ';
			nextPutAll: selector   ;
			nextPutAll: 'Contents';
			space ;
			nextPutAll: 'readStream' ;
			nextPut: $).
		aFamily compileSilently: iconGetter contents classified: aFamily iconsCategoryName notifying: nil.
			

! !

!ExternalIconSpec methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/10/2010 06:06'!
initialize 
	super initialize .
	sizes := ExternalIconFamily availableSizes ! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 11:06'!
name
	^ name! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 11/15/2010 15:22'!
name: anObject
	name := anObject ! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 12:39'!
resourcesFolderName
	^ resourcesFolderName! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 12:39'!
resourcesFolderName: anObject
	resourcesFolderName := anObject! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 23:08'!
sizes
	^ sizes! !

!ExternalIconSpec methodsFor: 'accessing' stamp: 'FernandoOlivero 4/17/2010 23:08'!
sizes: anObject
	sizes := anObject! !

!ExternalIconSpec methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/10/2010 06:06'!
validateCreationInto: aFamily 
	| root familyFolder fileResource extension imageWriterClass writer image stream all existing |
	all := aFamily loadedIconNames .
	existing := all select:[:each|
			(each  asString includesSubString: name )
			and:[(each  first: name size) = name]
			and:[
				| size |
				size := sizes detect:[:eachSize| each includesSubString: eachSize asString,'x', eachSize asString ] ifNone: nil.
				size notNil and:[ each size =  ( name size +  ( size asString,'x', size asString ) size)   ] ] ].
	self assert: existing size = sizes size.  
	sizes do:[:each| (aFamily iconNamed: name  size: each)].  ! !

Object subclass: #IconsFamilyBuilder
	instanceVariableNames: 'aliases'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExternalIconFamily'!

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 10:43'!
allIconFileNamesInTheResourcesFolder
	| familyDirectory sizeString  iconSizeDirectory |
	familyDirectory := FileDirectory default directoryNamed: self resourcesFolderName.
	sizeString := self availableSizes anyOne asString.
	iconSizeDirectory := familyDirectory directoryNamed: sizeString , 'x', sizeString.
	^ iconSizeDirectory fileNames select:[:each| each size > 4 and: [ self  validIconExtensions includes: (each last: 4) ]]  ! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:26'!
allIconFilesNames
	"override this method to provide a subset of all the available icons"
	^ self allIconFileNamesInTheResourcesFolder.! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:21'!
availableSizes 
	" in case you want a subset of all the available icons sizes in the external folder, override this method in your icon builder class"
	| familyDirectory icon16x16Directory sizesNames sizes |
	familyDirectory := FileDirectory default directoryNamed: self resourcesFolderName.
	sizesNames := familyDirectory directoryNames select:[:each| each includes: $x].
	sizes := sizesNames collect:[:each|  (each copyUpTo: $x ) asInteger ] .
	^ sizes asSet asSortedCollection.! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:11'!
build
	| specs secs family |
	specs := self iconsSpecs .
	specs do:[:each| each resourcesFolderName: self resourcesFolderName ].
	ExternalIconFamily createFamilyNamed: self iconFamilyName specs: specs .
	family := ExternalIconFamily named: self iconFamilyName.
	aliases notEmpty ifTrue:[ family useAllAliasesIn: aliases ].
	self
		compileDefaultIconNameMethodInto: family class ;
		compileAvailableSizesMethodInto: family class.! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:16'!
compileAvailableSizesMethodInto: aFamilyClass
	| stream |
	stream := '' writeStream.
	stream
		nextPutAll: 'availableSizes';
		cr;
		tab;
		nextPut: $^ ;
		nextPut: ${ ;
		space.
	self availableSizes
		do:[:each| stream nextPutAll: each asString ; space  ]
		separatedBy:[ stream nextPut: $. ; space ].
	stream nextPut: $}.		
	aFamilyClass compile: stream contents! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:00'!
compileDefaultIconNameMethodInto: aFamilyClass
	aFamilyClass compile: 'defaultIconName ^', '''' , self defaultIconName  , '''' .
	
	! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:07'!
defaultIconName
	^ self subclassResponsibility! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:18'!
iconFamilyName
	^ self subclassResponsibility! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 11:59'!
iconNameFrom: anIconFileName
	| invalidSelectorsLetters candidateIconName withoutPng upperCaseNext  stream  iconName defineAlias leadingDigit |
	invalidSelectorsLetters := self invalidSelectorsLetters.
	withoutPng := anIconFileName first: anIconFileName size - '.png' size .
	leadingDigit := withoutPng first isDigit.
	leadingDigit
		ifTrue:[ candidateIconName := 'x' , withoutPng ]
		ifFalse:[ candidateIconName := withoutPng ].
	stream := '' writeStream.
	defineAlias := false. 
	upperCaseNext := false.
	candidateIconName do:[:each |
		( each = $_ ) 
			ifTrue:[ upperCaseNext := true. defineAlias := true ]
			ifFalse:[
				(  invalidSelectorsLetters includes: each )
					ifTrue:[ stream nextPut: (self newLetterForReplacing: each) . defineAlias := true.]
					ifFalse:[ 
						upperCaseNext
							ifTrue:[ stream nextPut: each asUppercase . upperCaseNext := false ]
							ifFalse:[ stream nextPut: each ] ] ] ] .
	iconName := stream contents .
	( leadingDigit or:[ defineAlias] ) ifTrue:[ aliases at: withoutPng put: iconName  ].
	^ iconName ! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:25'!
iconsSpecs
	" in case you want a subset of all the available icons in the external folder, override this method in your icon builder class"
	| allFileNames  iconSpecs iconsSizes |
	iconSpecs := OrderedCollection new.
	iconsSizes := self availableSizes. 
	aliases := Dictionary new.
	self allIconFilesNames
		do:[:each|
			| iconSpec|
			iconSpec := ExternalIconSpec
				named: (self iconNameFrom: each ) 
				file: each
				sizes: iconsSizes.
			iconSpecs add: iconSpec ].
	^ iconSpecs	
		! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 11:58'!
invalidSelectorsLetters
	^ #($+ $- $- $% $^ $* $( $) ${ $} $< $> $@ $# $$ $!! )! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 11:58'!
newLetterForReplacing: aLetter 
	| i |
	i := self invalidSelectorsLetters indexOf: aLetter .
	i := (i-1) max: 0.
	^ Character value: $A asciiValue + i  
 
	! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/17/2010 12:35'!
resourcesFolderName 
	self subclassResponsibility ! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/14/2010 10:44'!
validIconExtensions
	^ { '.png' }! !

!IconsFamilyBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/10/2010 06:06'!
validateBuild
	| family |
	family := ExternalIconFamily named: self iconFamilyName .
	self assert: family notNil .
	self iconsSpecs do:[:each| each validateCreationInto: family  ].

	! !

IconsFamilyBuilder subclass: #OxygenIconsBuilder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExternalIconFamily'!

!OxygenIconsBuilder commentStamp: 'FernandoOlivero 11/14/2010 11:38' prior: 0!
OxygenIconsBuilder new build. 
OxygenIconsBuilder new allIconFileNamesInTheResourcesFolder
OxygenIconsBuilder new importedIconSpecsFromResourcesFolder explore. !

OxygenIconsBuilder subclass: #OxygenExampleIconsBuilder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExternalIconFamily'!

!OxygenExampleIconsBuilder commentStamp: 'FernandoOlivero 11/15/2010 14:30' prior: 0!
OxygenExampleIconsBuilder new build!

!OxygenExampleIconsBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:28'!
allIconFilesNames
	^ #( 'plus.png' 'redo.png' 'reload.png' 'remove.png' 'world.png' 'apply.png' 'delete_user.png'  'messagebox_warning.png' 'help_about.png' 'bell.png' 'document_save_all.png' 'edit_clear_history.png')
	

		! !

!OxygenExampleIconsBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 15:16'!
availableSizes 
	" in case you want a subset of all the available icons sizes in the external folder, override this method in your icon builder class"
	^ #( 16 32 64 )! !

!OxygenExampleIconsBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:31'!
iconFamilyName
	^ 'OxygenTinySubsetExample'! !

!OxygenIconsBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 14:07'!
defaultIconName
	^ 'messagebox_warning'.! !

!OxygenIconsBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 4/17/2010 12:33'!
iconFamilyName
	^ 'Oxygen'! !

!OxygenIconsBuilder methodsFor: 'as yet unclassified' stamp: 'FernandoOlivero 11/15/2010 13:25'!
resourcesFolderName 
	^ 'OxygenResources'  ! !
